'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Form = undefined;

var _objectWithoutProperties2 = require('babel-runtime/helpers/objectWithoutProperties');

var _objectWithoutProperties3 = _interopRequireDefault(_objectWithoutProperties2);

var _defineProperty2 = require('babel-runtime/helpers/defineProperty');

var _defineProperty3 = _interopRequireDefault(_defineProperty2);

var _extends3 = require('babel-runtime/helpers/extends');

var _extends4 = _interopRequireDefault(_extends3);

var _keys = require('babel-runtime/core-js/object/keys');

var _keys2 = _interopRequireDefault(_keys);

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _helperFunctions = require('./helperFunctions');

var _recompose = require('recompose');

var _Button = require('./Button');

var _Button2 = _interopRequireDefault(_Button);

var _SelectOne = require('./SelectOne');

var _SelectOne2 = _interopRequireDefault(_SelectOne);

var _SelectMany = require('./SelectMany');

var _SelectMany2 = _interopRequireDefault(_SelectMany);

var _ = require('.');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var Form = function Form(props) {
  var _props$baseClassName = props.baseClassName,
      baseClassName = _props$baseClassName === undefined ? 'form' : _props$baseClassName,
      className = props.className,
      style = props.style,
      values = props.values,
      touched = props.touched,
      errors = props.errors,
      children = props.children,
      handleChange = props.handleChange,
      handleSubmit = props.handleSubmit,
      setFieldValue = props.setFieldValue,
      setFieldTouched = props.setFieldTouched,
      isSubmitting = props.isSubmitting;


  var renderError = function renderError(type) {
    return errors && errors[type] && touched && touched[type] && _react2.default.createElement(
      'div',
      { className: baseClassName + '__error' },
      errors[type]
    );
  };

  var renderTextareaInputSocket = function renderTextareaInputSocket(_ref) {
    var type = _ref.type,
        label = _ref.label,
        _ref$required = _ref.required,
        required = _ref$required === undefined ? true : _ref$required;
    return _react2.default.createElement(
      'div',
      { className: baseClassName + '__socket ' + baseClassName + '__textarea__socket' },
      values[type] && _react2.default.createElement(
        _react.Fragment,
        null,
        _react2.default.createElement(
          'div',
          { className: baseClassName + '__label ' + baseClassName + '__textarea__label' },
          (0, _helperFunctions.capitalizeEveryWord)(label)
        ),
        _react2.default.createElement('textarea', {
          className: baseClassName + '__input ' + baseClassName + '__textarea__input',
          'data-testid': type.toLowerCase() + '-input',
          id: type,
          required: required,
          value: values[type],
          onChange: function onChange(e) {
            return setFieldValue(type, e.target.value);
          }
        })
      ),
      errors[type] && touched[type] && _react2.default.createElement(
        'div',
        { className: 'input-feedback' },
        errors[type]
      )
    );
  };

  var renderSelectManyWithCompositionSocket = function renderSelectManyWithCompositionSocket(_ref2) {
    var type = _ref2.type,
        label = _ref2.label,
        options = _ref2.options,
        currentOptions = _ref2.currentOptions,
        renderTrigger = _ref2.renderTrigger;

    return _react2.default.createElement(
      'div',
      { className: baseClassName + '__socket ' + baseClassName + '__select__socket' },
      _react2.default.createElement(
        'div',
        { className: baseClassName + '__label ' + baseClassName + '__select__label' },
        (0, _helperFunctions.capitalizeEveryWord)(label)
      ),
      _react2.default.createElement(
        _SelectMany2.default,
        {
          currentOptions: values[type] ? (0, _keys2.default)(values[type]).map(function (v) {
            return {
              value: v,
              label: options.find(function (o) {
                return o.value === v;
              }).label
            };
          }) : [],
          options: options,
          renderTrigger: renderTrigger,
          onChange: function onChange(value) {
            setFieldValue(type, value.reduce(function (acc, v) {
              acc[v.value] = 0;
              return acc;
            }, {}));
          },
          transitionType: ['dropdown', 'fade'],
          pivotFrom: 'DOWNRIGHT'
        },
        function (_ref3) {
          var getChildProps = _ref3.getChildProps,
              getChildrenProps = _ref3.getChildrenProps,
              currentOptions = _ref3.currentOptions;
          return _react2.default.createElement(
            'div',
            (0, _extends4.default)({}, getChildrenProps({ style: { width: '25.5rem' } })),
            options.map(function (option) {
              return _react2.default.createElement(
                _Button2.default,
                (0, _extends4.default)({}, getChildProps({
                  option: { value: option.value, label: option.label }
                }), {
                  key: option.value
                }),
                option.label
              );
            })
          );
        }
      ),
      values[type] && (0, _keys2.default)(values[type]).map(function (component) {
        return _react2.default.createElement(
          'div',
          { key: component, className: baseClassName + '__component' },
          _react2.default.createElement(
            'div',
            { className: baseClassName + '__component__label' },
            options.find(function (o) {
              return o.value === component;
            }).label
          ),
          _react2.default.createElement('input', {
            className: baseClassName + '__component__input',
            id: component,
            type: 'number',
            value: values[type][component],
            onChange: function onChange(v) {
              setFieldValue(type, (0, _extends4.default)({}, values[type], (0, _defineProperty3.default)({}, component, v.target.value)));
            }
          })
        );
      })
    );
  };

  var renderSelectManySocket = function renderSelectManySocket(_ref4) {
    var type = _ref4.type,
        label = _ref4.label,
        options = _ref4.options,
        currentOptions = _ref4.currentOptions,
        renderTrigger = _ref4.renderTrigger;

    return _react2.default.createElement(
      'div',
      { className: baseClassName + '__socket ' + baseClassName + '__select__socket' },
      _react2.default.createElement(
        'div',
        { className: baseClassName + '__label ' + baseClassName + '__select__label' },
        (0, _helperFunctions.capitalizeEveryWord)(label)
      ),
      _react2.default.createElement(
        _SelectMany2.default,
        {
          currentOptions: values[type],
          options: options,
          renderTrigger: renderTrigger,
          onChange: function onChange(value) {
            setFieldValue(type, value);
          },
          transitionType: ['dropdown', 'fade'],
          pivotFrom: 'DOWNRIGHT'
        },
        function (_ref5) {
          var getChildProps = _ref5.getChildProps,
              getChildrenProps = _ref5.getChildrenProps;
          return _react2.default.createElement(
            'div',
            (0, _extends4.default)({}, getChildrenProps({
              className: baseClassName + '__dropdown',
              style: { width: '25.5rem' } })),
            options.map(function (option) {
              return _react2.default.createElement(
                _Button2.default,
                (0, _extends4.default)({}, getChildProps({
                  option: { value: option.value, label: option.label }
                }), {
                  key: option.value
                }),
                option.label
              );
            })
          );
        }
      )
    );
  };

  var renderSelectOneSocket = function renderSelectOneSocket(_ref6) {
    var type = _ref6.type,
        label = _ref6.label,
        options = _ref6.options;

    return _react2.default.createElement(
      'div',
      { className: baseClassName + '__socket ' + baseClassName + '__select__socket' },
      _react2.default.createElement(
        'div',
        { className: baseClassName + '__label ' + baseClassName + '__select__label' },
        (0, _helperFunctions.capitalizeEveryWord)(label)
      ),
      _react2.default.createElement(
        _SelectOne2.default,
        {
          renderTrigger: function renderTrigger(_ref7) {
            var isOn = _ref7.isOn,
                currentOption = _ref7.currentOption,
                getTriggerProps = _ref7.getTriggerProps;
            return _react2.default.createElement(
              _Button2.default,
              (0, _extends4.default)({
                type: 'caretdown',
                isOn: isOn
              }, getTriggerProps({
                className: 'selectone__trigger',
                style: { border: '1px solid #ccc' }
              }), {
                colors: _.buttonStyles.monochrome
              }),
              currentOption ? currentOption.label : ''
            );
          },
          options: options,
          currentOption: values[type],
          onChange: function onChange(value) {
            setFieldValue(type, value);
          },
          transitionType: ['dropdown', 'fade'],
          pivotFrom: 'DOWNRIGHT'
        },
        function (_ref8) {
          var getChildProps = _ref8.getChildProps,
              getChildrenProps = _ref8.getChildrenProps,
              currentOption = _ref8.currentOption,
              toggleIsOn = _ref8.toggleIsOn;
          return _react2.default.createElement(
            'div',
            (0, _extends4.default)({}, getChildrenProps({ style: { width: '25.5rem' } })),
            options.map(function (option) {
              return _react2.default.createElement(
                _Button2.default,
                (0, _extends4.default)({}, getChildProps({
                  option: { value: option.value, label: option.label },
                  onClick: toggleIsOn
                }), {
                  isOn: currentOption.value === option.value,
                  key: option.value
                }),
                option.label
              );
            })
          );
        }
      )
    );
  };

  var renderSubmitButton = function renderSubmitButton() {
    var _ref9 = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

    var label = _ref9.label,
        props = (0, _objectWithoutProperties3.default)(_ref9, ['label']);
    return _react2.default.createElement(
      _Button2.default,
      (0, _extends4.default)({
        invert: true,
        colors: 'surfing',
        onClick: handleSubmit,
        dataTestId: 'submit',
        disabled: isSubmitting,
        style: { width: '24rem', borderRadius: '.25rem' }
      }, props),
      label
    );
  };

  var renderTextInputSocket = function renderTextInputSocket(_ref10) {
    var type = _ref10.type,
        label = _ref10.label,
        sublabel = _ref10.sublabel,
        _ref10$options = _ref10.options,
        options = _ref10$options === undefined ? { required: true, autoFocus: false, autoComplete: '' } : _ref10$options,
        props = (0, _objectWithoutProperties3.default)(_ref10, ['type', 'label', 'sublabel', 'options']);

    return _react2.default.createElement(
      'div',
      (0, _extends4.default)({ className: baseClassName + '__socket' }, props),
      _react2.default.createElement('input', {
        id: type,
        className: baseClassName + '__socket__input ' + baseClassName + '__socket__input__' + type.toLowerCase(),
        type: 'text',
        required: options.required ? options.required : true,
        autoFocus: options.autoFocus ? options.autoFocus : false,
        value: values[type],
        autoComplete: options.autoComplete ? options.autoComplete : '',
        onChange: handleChange,
        onBlur: function onBlur() {
          return setFieldTouched(type);
        }
      }),
      _react2.default.createElement(
        'div',
        { className: baseClassName + '__label ' + baseClassName + '__socket__label' },
        (0, _helperFunctions.capitalizeEveryWord)(label)
      ),
      _react2.default.createElement('div', { className: baseClassName + '__socket__bar' }),
      sublabel && _react2.default.createElement(
        'div',
        { className: baseClassName + '__socket__sublabel' },
        sublabel
      ),
      renderError(type)
    );
  };

  var renderGroup = function renderGroup(_ref11) {
    var label = _ref11.label,
        renderChildren = _ref11.renderChildren;
    return _react2.default.createElement(
      'div',
      { className: baseClassName + '__group' },
      _react2.default.createElement(
        'div',
        { className: baseClassName + '__label ' + baseClassName + '__group__label' },
        label
      ),
      _react2.default.createElement(
        'div',
        { className: baseClassName + '__children ' + baseClassName + '__group__children' },
        renderChildren()
      )
    );
  };

  var renderCheckboxSocket = function renderCheckboxSocket(_ref12) {
    var label = _ref12.label,
        type = _ref12.type;
    return _react2.default.createElement(
      'div',
      { className: baseClassName + '__checkbox' },
      _react2.default.createElement(
        'div',
        { className: baseClassName + '__label ' + baseClassName + '__checkbox__label' },
        label
      ),
      _react2.default.createElement('input', {
        id: type,
        className: baseClassName + '__checkbox__input',
        type: 'checkbox',
        checked: values[type],
        onChange: handleChange
      })
    );
  };

  return _react2.default.createElement(
    'form',
    {
      onSubmit: handleSubmit,
      className: className ? className : 'form',
      style: style
    },
    children({
      renderTextInputSocket: renderTextInputSocket,
      renderTextareaInputSocket: renderTextareaInputSocket,
      renderSelectManyWithCompositionSocket: renderSelectManyWithCompositionSocket,
      renderSelectOneSocket: renderSelectOneSocket,
      renderSelectManySocket: renderSelectManySocket,
      renderCheckboxSocket: renderCheckboxSocket,
      renderGroup: renderGroup,
      renderSubmitButton: renderSubmitButton
    }),
    errors.firebase && _react2.default.createElement(
      'div',
      {
        'data-testid': 'registeraccountmodal-formerror-firebase',
        className: 'input-feedback'
      },
      'error!',
      errors.firebase
    ),
    _react2.default.createElement('input', { type: 'submit', style: { visibility: 'hidden', height: 0, width: 0 } })
  );
};

exports.Form = Form;
Form.defaultProps = {
  handleSubmit: function handleSubmit() {
    return console.log('Form: handleSubmit');
  },
  style: {}
};
var enhance = (0, _recompose.compose)((0, _recompose.onlyUpdateForKeys)(['values', 'touched', 'errors', 'children']), (0, _recompose.lifecycle)({
  componentDidMount: function componentDidMount() {
    var onMount = this.props.onMount;

    onMount && onMount();
  },
  componentWillUnmount: function componentWillUnmount() {
    var onUnmount = this.props.onUnmount;

    onUnmount && onUnmount();
  }
}));

exports.default = enhance(Form);